@@ -5,9 +5,9 @@ A command-line tool that automatically generates conventional commit messages us
 Supports multiple AI providers including OpenRouter, Ollama, and custom providers.
 """
 
-__version__ = "1.0.9"
-__author__ = "Mobio Team"
-__email__ = "dev@mobio.vn"
+__version__ = "1.1.1"
+__author__ = "Mobio Company"
+__email__ = "contact@mobio.vn"
 
 try:
     from pkg_resources import declare_namespace
